==> CloudClientStandardAWS_v2.0.1.zip: com/clustercontrol/ws/aws/IpPermission.java <==

package com.clustercontrol.ws.aws;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>ipPermission complex typeJavaNXB
 * 
 * <p>̃XL[}EtOǵÃNXɊ܂܂\Recw肵܂B
 * 
 * <pre>
 * &lt;complexType name="ipPermission">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="fromPort" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="ipProtocol" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="ipRanges" type="{http://www.w3.org/2001/XMLSchema}string" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="toPort" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="userIdGroupPairs" type="{http://aws.ws.clustercontrol.com}userIdGroupPair" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ipPermission", propOrder = {
    "fromPort",
    "ipProtocol",
    "ipRanges",
    "toPort",
    "userIdGroupPairs"
})
public class IpPermission {

    protected Integer fromPort;
    protected String ipProtocol;
    @XmlElement(nillable = true)
    protected List<String> ipRanges;
    protected Integer toPort;
    @XmlElement(nillable = true)
    protected List<UserIdGroupPair> userIdGroupPairs;

    /**
     * fromPortvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getFromPort() {
        return fromPort;
    }

    /**
     * fromPortvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setFromPort(Integer value) {
        this.fromPort = value;
    }

    /**
     * ipProtocolvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIpProtocol() {
        return ipProtocol;
    }

    /**
     * ipProtocolvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIpProtocol(String value) {
        this.ipProtocol = value;
    }

    /**
     * Gets the value of the ipRanges property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the ipRanges property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getIpRanges().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getIpRanges() {
        if (ipRanges == null) {
            ipRanges = new ArrayList<String>();
        }
        return this.ipRanges;
    }

    /**
     * toPortvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getToPort() {
        return toPort;
    }

    /**
     * toPortvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setToPort(Integer value) {
        this.toPort = value;
    }

    /**
     * Gets the value of the userIdGroupPairs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the userIdGroupPairs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getUserIdGroupPairs().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link UserIdGroupPair }
     * 
     * 
     */
    public List<UserIdGroupPair> getUserIdGroupPairs() {
        if (userIdGroupPairs == null) {
            userIdGroupPairs = new ArrayList<UserIdGroupPair>();
        }
        return this.userIdGroupPairs;
    }

}

==> CloudClientStandardAWS_v2.0.3.zip: com/clustercontrol/ws/aws/IpPermission.java <==

package com.clustercontrol.ws.aws;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>ipPermission complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="ipPermission">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="fromPort" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="ipProtocol" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="ipRanges" type="{http://www.w3.org/2001/XMLSchema}string" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="toPort" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="userIdGroupPairs" type="{http://aws.ws.clustercontrol.com}userIdGroupPair" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ipPermission", propOrder = {
    "fromPort",
    "ipProtocol",
    "ipRanges",
    "toPort",
    "userIdGroupPairs"
})
public class IpPermission {

    protected Integer fromPort;
    protected String ipProtocol;
    @XmlElement(nillable = true)
    protected List<String> ipRanges;
    protected Integer toPort;
    @XmlElement(nillable = true)
    protected List<UserIdGroupPair> userIdGroupPairs;

    /**
     * fromPortプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getFromPort() {
        return fromPort;
    }

    /**
     * fromPortプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setFromPort(Integer value) {
        this.fromPort = value;
    }

    /**
     * ipProtocolプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIpProtocol() {
        return ipProtocol;
    }

    /**
     * ipProtocolプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIpProtocol(String value) {
        this.ipProtocol = value;
    }

    /**
     * Gets the value of the ipRanges property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the ipRanges property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getIpRanges().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getIpRanges() {
        if (ipRanges == null) {
            ipRanges = new ArrayList<String>();
        }
        return this.ipRanges;
    }

    /**
     * toPortプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getToPort() {
        return toPort;
    }

    /**
     * toPortプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setToPort(Integer value) {
        this.toPort = value;
    }

    /**
     * Gets the value of the userIdGroupPairs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the userIdGroupPairs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getUserIdGroupPairs().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link UserIdGroupPair }
     * 
     * 
     */
    public List<UserIdGroupPair> getUserIdGroupPairs() {
        if (userIdGroupPairs == null) {
            userIdGroupPairs = new ArrayList<UserIdGroupPair>();
        }
        return this.userIdGroupPairs;
    }

}
